<template>
  <a-card
    :bordered="false"
    class="card-area"
  >
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>
    <a-table
      ref="table"
      bordered
      size="middle"
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      :loading="loading"
      :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange,type:getType()}"
      @change="handleTableChange"
    >
    </a-table>
  </a-card>
  
</template>

<script>
import { requestPut } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import { deleteAction, getAction, postAction } from '../../../../api/manage'

export default {
  name: 'WarehouseDepartModelRight',
  mixins: [JeecgListMixin],
  components: {
    JInput,
    JEllipsis,
  },
  props:{
    mainId:{
        type:String,
        default:'',
        required:false
    },
    departInfo:{
        type:Object,
        default:{},
        required:false
    },
    originTargetKeys:{
        type:Array,
        required:false
    },
    addId:{
        type:String,
        default:'',
        required:false
    },
  },
  data() {
    return {
      //默认排序
      disableMixinCreated:true,
      selected:'',
      addDepartIds:[],
      factoryType:0,
      preVisible:false,
      isorter: {
        column: 'num',
        order: 'asc',
      },
      dataSource:[],
      columns: [
        {
          title: '组织编码',
          align: "center",
          dataIndex: 'orgCode',
          scopedSlots: {
            customRender: 'orgCode',
          },
          sorter: true,
          width:100
        },
        {
          title: '组织名称',

          align: "center",
          dataIndex: 'departName',
          scopedSlots: {
            customRender: 'departName',
          },
          sorter: true,
          width:100
        },
      ],
      url: {
        list: "/base/depart/list",
      },
    };
  },
  methods: {
    onSelectChange(selectedRowKeys, selectionRows) {
        this.selectedRowKeys = selectedRowKeys;
        this.selectionRows = selectionRows;
        this.addDepartIds = selectionRows
    },
   clearSelectList(){
    this.addDepartIds=[];
    this.selectedRowKeys=[];
   },
   getSelected(){
    var ids = "";
        for (var a = 0; a < this.originTargetKeys.length; a++) {
          ids += this.originTargetKeys[a] + ",";
        }
    this.selected=ids;
   },
   getType(){
      if(!this.addId||this.addId==''){
          return 'checkbox'
      }else{
          return 'radio'
      }
     }
  },
  created(){
    this.getSelected();
  },
  watch:{
     departInfo:{
       immediate:true,
       deep:true,
       handler(val) {
        this.queryParam["parentId"]=val.parentId;
        this.queryParam["version"]=val.version;
        this.queryParam["selected"]=this.selected;
        this.loadData(1);
       }
     },
     addDepartIds:{
       immediate:true,
       deep:true,
       handler(val) {
        this.$emit("getAddDepartIds",val);
       }
     },
    
    }

}
</script>
<style>
@import '~@assets/less/common.less';

.frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.notShow{
  display: none
}
</style>